@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -29,7 +29,6 @@
 #ifndef TNTDB_IFACE_ICONNECTIONMANAGER_H
 #define TNTDB_IFACE_ICONNECTIONMANAGER_H
 
-#include <cxxtools/noncopyable.h>
 #include <string>
 
 #define TNTDB_DRIVER_PRAEFIX connectionManager1_
@@ -44,11 +43,15 @@ namespace tntdb
 {
   class Connection;
 
-  class IConnectionManager : private cxxtools::NonCopyable
+  class IConnectionManager
   {
+      IConnectionManager(const IConnectionManager&) { }
+      IConnectionManager& operator=(const IConnectionManager&) { return *this; }
+
     public:
+      IConnectionManager() { }
       virtual ~IConnectionManager() { }
-      virtual Connection connect(const std::string& url) = 0;
+      virtual Connection connect(const std::string& url, const std::string& username, const std::string& password) = 0;
   };
 }
 
