@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2011 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -48,7 +48,7 @@ namespace tntdb
         tntdb::Connection primaryConnection;
 
       public:
-        explicit Connection(const char* conninfo);
+        Connection(const std::string& url, const std::string& username, const std::string& password);
         ~Connection();
 
         void beginTransaction();
@@ -60,6 +60,7 @@ namespace tntdb
         tntdb::Row selectRow(const std::string& query);
         tntdb::Value selectValue(const std::string& query);
         tntdb::Statement prepare(const std::string& query);
+        tntdb::Statement prepareWithLimit(const std::string& query, const std::string& limit, const std::string& offset);
         bool ping();
         long lastInsertId(const std::string& name);
         void lockTable(const std::string& tablename, bool exclusive);
