@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -34,8 +34,29 @@
 
 namespace tntdb
 {
+  /**
+
+   This namespace contains the implementation of the Sqlite driver for tntdb.
+
+   The driver makes it possible to access a Sqlite3 database using tntdb.
+
+   Note that only sqlite api version 3 is supported.
+
+   To get a connection to a Sqlite3 file, the dburl to the tntdb::connect
+   function must start with "sqlite:". The remaining string is passed to the
+   `sqlite3_open` function of sqlite.
+
+   A typical connection with a Sqlite3 driver looks like that:
+
+   @code
+     tntdb::Connection conn = tntdb::connect("sqlite:mydatabase.db");
+   @endcode
+
+   */
+
   namespace sqlite
   {
+    /// Implements a connection to a Sqlite3 database file.
     class Connection : public IStmtCacheConnection
     {
         sqlite3* db;
@@ -54,6 +75,7 @@ namespace tntdb
         tntdb::Row selectRow(const std::string& query);
         tntdb::Value selectValue(const std::string& query);
         tntdb::Statement prepare(const std::string& query);
+        tntdb::Statement prepareWithLimit(const std::string& query, const std::string& limit, const std::string& offset);
         bool ping();
         long lastInsertId(const std::string& name);
         void lockTable(const std::string& tablename, bool exclusive);
