@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -63,9 +63,9 @@ namespace tntdb
   {
     struct tm tm;
     memset(&tm, 0, sizeof(struct tm));
-    tm.tm_mday = day;
-    tm.tm_mon = month - 1;
-    tm.tm_year = year - 1900;
+    tm.tm_mday = _day;
+    tm.tm_mon = _month - 1;
+    tm.tm_year = _year - 1900;
 
     time_t t = mktime(&tm);
     localtime_r(&t, &tm);
@@ -79,7 +79,7 @@ namespace tntdb
     // format YYYY-MM-DD
     //        0....+....1
     char ret[10];
-    unsigned short n = year;
+    unsigned short n = _year;
     ret[3] = '0' + n % 10;
     n /= 10;
     ret[2] = '0' + n % 10;
@@ -88,11 +88,11 @@ namespace tntdb
     n /= 10;
     ret[0] = '0' + n % 10;
     ret[4] = '-';
-    ret[5] = '0' + month / 10;
-    ret[6] = '0' + month % 10;
+    ret[5] = '0' + _month / 10;
+    ret[6] = '0' + _month % 10;
     ret[7] = '-';
-    ret[8] = '0' + day / 10;
-    ret[9] = '0' + day % 10;
+    ret[8] = '0' + _day / 10;
+    ret[9] = '0' + _day % 10;
 
     return std::string(ret, 10);
   }
