@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -67,7 +67,7 @@ namespace tntdb
     // format YYYY-MM-DD hh:mm:ss.sss
     //        0....+....1....+....2....+
     char ret[25];
-    unsigned short n = year;
+    unsigned short n = _year;
     ret[3] = '0' + n % 10;
     n /= 10;
     ret[2] = '0' + n % 10;
@@ -76,22 +76,22 @@ namespace tntdb
     n /= 10;
     ret[0] = '0' + n % 10;
     ret[4] = '-';
-    ret[5] = '0' + month / 10;
-    ret[6] = '0' + month % 10;
+    ret[5] = '0' + _month / 10;
+    ret[6] = '0' + _month % 10;
     ret[7] = '-';
-    ret[8] = '0' + day / 10;
-    ret[9] = '0' + day % 10;
+    ret[8] = '0' + _day / 10;
+    ret[9] = '0' + _day % 10;
     ret[10] = ' ';
-    ret[11] = '0' + hour / 10;
-    ret[12] = '0' + hour % 10;
+    ret[11] = '0' + _hour / 10;
+    ret[12] = '0' + _hour % 10;
     ret[13] = ':';
-    ret[14] = '0' + minute / 10;
-    ret[15] = '0' + minute % 10;
+    ret[14] = '0' + _minute / 10;
+    ret[15] = '0' + _minute % 10;
     ret[16] = ':';
-    ret[17] = '0' + second / 10;
-    ret[18] = '0' + second % 10;
+    ret[17] = '0' + _second / 10;
+    ret[18] = '0' + _second % 10;
     ret[19] = '.';
-    n = millis;
+    n = _millis;
     ret[22] = '0' + n % 10;
     n /= 10;
     ret[21] = '0' + n % 10;
@@ -172,5 +172,5 @@ namespace tntdb
 
     return ret;
   }
-
 }
+
