@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2006 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,18 +15,19 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <tntdb/librarymanager.h>
+#include <tntdb/error.h>
 #include <cxxtools/log.h>
 #include <cxxtools/systemerror.h>
 #include <cxxtools/directory.h>
@@ -60,11 +61,21 @@ namespace tntdb
       log_debug("opening library \"" << libraryPrefix << driverName << "\" failed: " << e.what());
     }
 
-    if (!lib)
+    try
     {
-      std::string d = DRIVERDIR + cxxtools::Directory::sep() + libraryPrefix + driverName;
-      log_debug("loading library \"" << d << '"');
-      lib = cxxtools::Library(d);
+      if (!lib)
+      {
+        std::string d = DRIVERDIR + cxxtools::Directory::sep() + libraryPrefix + driverName;
+        log_debug("loading library \"" << d << '"');
+        lib = cxxtools::Library(d);
+      }
+    }
+    catch (const std::exception& e)
+    {
+      std::ostringstream msg;
+      msg << "failed to load driver \"" << libraryPrefix << driverName << '"';
+      log_warn(msg.str() << ": " << e.what());
+      throw Error(msg.str());
     }
 
     std::string symbolName = TNTDB_TOSTRING(TNTDB_DRIVER_PRAEFIX) + driverName;
