@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -96,12 +96,13 @@ namespace tntdb
     void BindValues::initOutBuffer(unsigned n, MYSQL_FIELD& f)
     {
       log_debug("initOutBuffer name=" << f.name << " n=" << n << " length=" << f.length << " type=" << f.type
-        << " max_length=" << f.max_length);
+        << " max_length=" << f.max_length << " flags=" << f.flags << " unsigned=" << bool(f.flags & UNSIGNED_FLAG));
 
       reserve(values[n], std::max(f.length, f.max_length));
       if (f.type == 0)
         log_debug("no type in metadata for field " << n << "; using MYSQL_TYPE_VAR_STRING");
       values[n].buffer_type = f.type ? f.type : MYSQL_TYPE_VAR_STRING;
+      values[n].is_unsigned = bool(f.flags & UNSIGNED_FLAG);
       if (f.name)
         bindAttributes[n].name = f.name;
       else
