@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -137,7 +137,7 @@ namespace tntdb
       return ptr.getPointer();
     }
 
-    Statement::Statement(const tntdb::Connection& conn_, MYSQL* mysql_,
+    Statement::Statement(Connection* conn_, MYSQL* mysql_,
       const std::string& query_)
       : conn(conn_),
         mysql(mysql_),
@@ -364,7 +364,7 @@ namespace tntdb
       if (!found)
         log_warn("hostvar \"" << col << "\" not found");
     }
-    
+
     void Statement::setDecimal(const std::string& col, const Decimal& data)
     {
       log_debug("statement " << stmt << " setDecimal(\"" << col << "\", " << data << ')');
@@ -517,7 +517,7 @@ namespace tntdb
       log_debug("execute statement " << stmt);
       if (hostvarMap.empty())
       {
-        return conn.execute(query);
+        return conn->execute(query);
       }
       else
       {
@@ -533,7 +533,7 @@ namespace tntdb
       log_debug("select");
 
       if (hostvarMap.empty())
-        return conn.select(query);
+        return conn->select(query);
 
       if (fields)
         getRow();
@@ -559,7 +559,7 @@ namespace tntdb
       log_debug("selectRow");
 
       if (hostvarMap.empty())
-        return conn.selectRow(query);
+        return conn->selectRow(query);
 
       if (fields)
         getRow();
