@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2007 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -118,31 +118,33 @@ namespace tntdb
       // workaround for OCI problem: OCI redirects SIGINT, which causes Ctrl-C to fail
       SighandlerSaver sighandlerSaver(SIGINT);
 
+      pid = ::getpid();
+
       sword ret;
 
-      log_debug("create oracle environment");
-      ret = OCIEnvCreate(&envhp, OCI_OBJECT, 0, 0, 0, 0, 0, 0);
+      log_finer("create oracle environment");
+      ret = OCIEnvCreate(&envhp, OCI_OBJECT|OCI_THREADED|OCI_NO_MUTEX, 0, 0, 0, 0, 0, 0);
       if (ret != OCI_SUCCESS)
         throw Error("cannot create environment handle");
-      log_debug("environment handle => " << envhp);
+      log_finer("environment handle => " << envhp);
 
-      log_debug("allocate error handle");
+      log_finer("allocate error handle");
       ret = OCIHandleAlloc(envhp, (void**)&errhp, OCI_HTYPE_ERROR, 0, 0);
       if (ret != OCI_SUCCESS)
         throw Error("cannot create error handle");
-      log_debug("error handle => " << errhp);
+      log_finer("error handle => " << errhp);
 
-      log_debug("allocate server handle");
+      log_finer("allocate server handle");
       ret = OCIHandleAlloc(envhp, (void**)&srvhp, OCI_HTYPE_SERVER, 0, 0);
       checkError(ret, "OCIHandleAlloc(OCI_HTYPE_SERVER)");
-      log_debug("server handle => " << srvhp);
+      log_finer("server handle => " << srvhp);
 
-      log_debug("allocate service handle");
+      log_finer("allocate service handle");
       ret = OCIHandleAlloc(envhp, (void**)&svchp, OCI_HTYPE_SVCCTX, 0, 0);
       checkError(ret, "OCIHandleAlloc(OCI_HTYPE_SVCCTX)");
-      log_debug("service handle => " << svchp);
+      log_finer("service handle => " << svchp);
 
-      log_debug("attach to server");
+      log_finer("attach to server");
       ret = OCIServerAttach(srvhp, errhp, reinterpret_cast<const text*>(dblink.data()), dblink.size(), 0);
       checkError(ret, "OCIServerAttach");
 
@@ -150,12 +152,12 @@ namespace tntdb
       ret = OCIAttrSet(svchp, OCI_HTYPE_SVCCTX, srvhp, 0, OCI_ATTR_SERVER, errhp);
       checkError(ret, "OCIAttrSet(OCI_ATTR_SERVER)");
 
-      log_debug("allocate session handle");
+      log_finer("allocate session handle");
       ret = OCIHandleAlloc((dvoid*)envhp, (dvoid**)&usrhp, OCI_HTYPE_SESSION, 0, (dvoid**)0);
       checkError(ret, "OCIHandleAlloc(OCI_HTYPE_SESSION)");
 
       /* set username attribute in user session handle */
-      log_debug("set username attribute in session handle");
+      log_finer("set username attribute in session handle");
       ret = OCIAttrSet(usrhp, OCI_HTYPE_SESSION,
         reinterpret_cast<void*>(const_cast<char*>(user.data())),
         user.size(), OCI_ATTR_USERNAME, errhp);
@@ -168,7 +170,7 @@ namespace tntdb
       checkError(ret, "OCIAttrSet(OCI_ATTR_PASSWORD)");
 
       /* start session */
-      log_debug("start session");
+      log_finer("start session");
       ret = OCISessionBegin(svchp, errhp, usrhp, OCI_CRED_RDBMS, OCI_DEFAULT);
       checkError(ret, "OCISessionBegin");
 
@@ -202,7 +204,7 @@ namespace tntdb
       }
     }
 
-    Connection::Connection(const char* conninfo_)
+    Connection::Connection(const std::string& url, const std::string& username, const std::string& password)
       : envhp(0),
         srvhp(0),
         errhp(0),
@@ -210,10 +212,16 @@ namespace tntdb
         svchp(0),
         transactionActive(0)
     {
-      std::string conninfo(conninfo_);
-      std::string user = extractAttribute(conninfo, "user=");
-      std::string passwd = extractAttribute(conninfo, "passwd=");
-      logon(conninfo, user, passwd);
+      std::string conninfo(url);
+      std::string au = extractAttribute(conninfo, "user=");
+      std::string ap = extractAttribute(conninfo, "passwd=");
+      log_warn_if(!ap.empty(), "password should not be given in dburl");
+      log_warn_if(!au.empty() && !username.empty(), "username given in url and parameter");
+      log_warn_if(!ap.empty() && !password.empty(), "password given in url and parameter");
+      if (au.empty() && ap.empty())
+        logon(conninfo, username, password);
+      else
+        logon(conninfo, au, ap);
     }
 
     Connection::~Connection()
@@ -226,7 +234,7 @@ namespace tntdb
 
         try
         {
-          log_debug("OCISessionEnd");
+          log_finer("OCISessionEnd");
           ret = OCISessionEnd(svchp, errhp, usrhp, OCI_DEFAULT);
           checkError(ret, "OCISessionEnd");
         }
@@ -237,7 +245,7 @@ namespace tntdb
 
         try
         {
-          log_debug("OCIServerDetach");
+          log_finer("OCIServerDetach");
           ret = OCIServerDetach(srvhp, errhp, OCI_DEFAULT);
           checkError(ret, "OCIServerDetach");
         }
@@ -246,10 +254,10 @@ namespace tntdb
           log_error(e.what());
         }
 
-        log_debug("OCIHandleFree(" << envhp << ')');
+        log_finer("OCIHandleFree(" << envhp << ')');
         ret = OCIHandleFree(envhp, OCI_HTYPE_ENV);
         if (ret == OCI_SUCCESS)
-          log_debug("handle released");
+          log_finer("handle released");
         else
           log_error("OCIHandleFree failed");
       }
@@ -305,6 +313,48 @@ namespace tntdb
       return tntdb::Statement(new Statement(this, query));
     }
 
+    tntdb::Statement Connection::prepareWithLimit(const std::string& query, const std::string& limit, const std::string& offset)
+    {
+      std::string q;
+      if (limit.empty())
+      {
+        if (offset.empty())
+        {
+          q = query;
+        }
+        else
+        {
+          // no limit, just offset
+          q = "select * from (select a.*, rownum tntdbrownum from(";
+          q += query;
+          q += ")a) where tntdbrownum > :";
+          q += offset;
+        }
+      }
+      else if (offset.empty())
+      {
+        // just limit, no offset
+        q = "select * from (select a.*, rownum tntdbrownum from(";
+        q += query;
+        q += ")a) where tntdbrownum <= :";
+        q += limit;
+      }
+      else
+      {
+        // limit and offset set
+        q = "select * from (select a.*, rownum tntdbrownum from(";
+        q += query;
+        q += ")a) where tntdbrownum > :";
+        q += offset;
+        q += " and tntdbrownum <= :";
+        q += offset;
+        q += " + :";
+        q += limit;
+      }
+
+      return prepare(q);
+    }
+
     void Connection::clearStatementCache()
     {
       IStmtCacheConnection::clearStatementCache();
@@ -315,6 +365,23 @@ namespace tntdb
     {
       try
       {
+        if (pid != getpid())
+        {
+          // database connection is not valid any more after a fork
+          log_warn("pid has changed; current pid=" << getpid() << " connection pid=" << pid << ", release environment handle");
+
+          clearStatementCache();
+          seqStmt.clear();
+
+          sword ret = OCIHandleFree(envhp, OCI_HTYPE_ENV);
+          if (ret != OCI_SUCCESS)
+            log_error("OCIHandleFree(" << envhp << " OCI_HTYPE_ENV) failed");
+
+          envhp = 0;
+
+          return false;
+        }
+
         // OCIPing crashed on oracle 10.2.0.4.0
 #if OCI_MAJOR_VERSION >= 11
         checkError(OCIPing(svchp, errhp, OCI_DEFAULT), "OCIPing");
