@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2012 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -219,7 +219,7 @@ namespace tntdb
           _data = new char[_n * sizeof(unsigned long)];
           ret = OCIDefineByPos(stmt->getHandle(), &_defp,
             stmt->getErrorHandle(), pos + 1, _data,
-            sizeof(sizeof(unsigned long)), SQLT_UIN, _nullind, _len, 0, OCI_DEFAULT);
+            sizeof(unsigned long), SQLT_UIN, _nullind, _len, 0, OCI_DEFAULT);
           break;
 
         case SQLT_FLT:
@@ -247,7 +247,7 @@ namespace tntdb
             _data = new char[_n * sizeof(OCILobLocator*)];
 
             OCIDateTime** p = reinterpret_cast<OCIDateTime**>(_data);
-            log_debug("OCIDescriptorAlloc(OCI_DTYPE_TIMESTAMP) (" << _n << " times)");
+            log_debug("OCIDescriptorAlloc(OCI_DTYPE_LOB) (" << _n << " times)");
             for (unsigned n = 0; n < _n; ++n)
             {
               ret = OCIDescriptorAlloc(stmt->getConnection()->getEnvHandle(),
@@ -261,6 +261,14 @@ namespace tntdb
           }
           break;
 
+        case SQLT_BIN:
+          log_debug("OCIDefineByPos(SQLT_BIN)");
+          _data = new char[(_collen + 16) * _n];
+          ret = OCIDefineByPos(stmt->getHandle(), &_defp,
+            stmt->getErrorHandle(), pos + 1, _data,
+            (_collen + 16), SQLT_BIN, _nullind, _len, 0, OCI_DEFAULT);
+          break;
+
         default:
           log_debug("OCIDefineByPos(SQLT_AFC)");
           _data = new char[(_collen + 16) * _n];
@@ -315,12 +323,16 @@ namespace tntdb
 
     bool MultiValue::isNull(unsigned n) const
     {
+      log_debug("isNull(" << n << ')');
+
       return _nullind[n] != 0;
     }
 
     bool MultiValue::getBool(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getBool(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -344,7 +356,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           int value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(int), OCI_NUMBER_SIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value != 0;
@@ -360,7 +372,9 @@ namespace tntdb
 
     short MultiValue::getShort(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getShort(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -382,7 +396,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           short value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(short), OCI_NUMBER_SIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -395,7 +409,9 @@ namespace tntdb
 
     int MultiValue::getInt(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getInt(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -417,7 +433,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           int value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(int), OCI_NUMBER_SIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -430,7 +446,9 @@ namespace tntdb
 
     long MultiValue::getLong(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getLong(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -452,7 +470,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           long value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(long), OCI_NUMBER_SIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -465,12 +483,16 @@ namespace tntdb
 
     int32_t MultiValue::getInt32(unsigned n) const
     {
+      log_debug("getInt32(" << n << "), type=" << _type);
+
       return getInt(n);
     }
 
     unsigned short MultiValue::getUnsignedShort(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getUnsignedShort(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -492,7 +514,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           unsigned short value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(unsigned short), OCI_NUMBER_UNSIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -505,7 +527,9 @@ namespace tntdb
 
     unsigned MultiValue::getUnsigned(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getUnsigned(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -527,7 +551,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           unsigned value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(unsigned), OCI_NUMBER_UNSIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -540,7 +564,9 @@ namespace tntdb
 
     unsigned long MultiValue::getUnsignedLong(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getUnsignedLong(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -562,7 +588,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           unsigned long value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(unsigned long), OCI_NUMBER_UNSIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -575,12 +601,16 @@ namespace tntdb
 
     uint32_t MultiValue::getUnsigned32(unsigned n) const
     {
+      log_debug("getUnsigned32(" << n << "), type=" << _type);
+
       return getUnsigned(n);
     }
 
     int64_t MultiValue::getInt64(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getInt64(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -602,7 +632,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           int64_t value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(int64_t), OCI_NUMBER_SIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -615,7 +645,9 @@ namespace tntdb
 
     uint64_t MultiValue::getUnsigned64(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getUnsigned64(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -637,7 +669,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           uint64_t value;
-          log_debug("OCINumberToInt");
+          log_finer("OCINumberToInt");
           sword ret = OCINumberToInt(_conn->getErrorHandle(), &number(n), sizeof(uint64_t), OCI_NUMBER_UNSIGNED, &value);
           _conn->checkError(ret, "OCINumberToInt");
           return value;
@@ -650,7 +682,9 @@ namespace tntdb
 
     Decimal MultiValue::getDecimal(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getDecimal(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -679,7 +713,9 @@ namespace tntdb
 
     float MultiValue::getFloat(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getFloat(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -701,7 +737,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           float value;
-          log_debug("OCINumberToReal");
+          log_finer("OCINumberToReal");
           sword ret = OCINumberToReal(_conn->getErrorHandle(), &number(n), sizeof(float), &value);
           _conn->checkError(ret, "OCINumberToReal");
           return value;
@@ -714,7 +750,9 @@ namespace tntdb
 
     double MultiValue::getDouble(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getDouble(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -736,7 +774,7 @@ namespace tntdb
         case SQLT_VNU:
         {
           double value;
-          log_debug("OCINumberToReal");
+          log_finer("OCINumberToReal");
           sword ret = OCINumberToReal(_conn->getErrorHandle(), &number(n), sizeof(double), &value);
           _conn->checkError(ret, "OCINumberToReal");
           return value;
@@ -749,7 +787,9 @@ namespace tntdb
 
     char MultiValue::getChar(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getChar(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -772,7 +812,9 @@ namespace tntdb
 
     void MultiValue::getString(unsigned n, std::string& ret) const
     {
-      if (_type != SQLT_AFC && _type != SQLT_CHR && isNull(n))
+      log_debug("getString(" << n << "), type=" << _type);
+
+      if (_type != SQLT_AFC && _type != SQLT_CHR && _nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -805,7 +847,9 @@ namespace tntdb
 
     void MultiValue::getBlob(unsigned n, tntdb::Blob& ret) const
     {
-      if (isNull(n))
+      log_debug("getBlob(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -832,7 +876,9 @@ namespace tntdb
 
     Date MultiValue::getDate(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getDate(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -850,7 +896,9 @@ namespace tntdb
 
     Time MultiValue::getTime(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("getTime(" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
@@ -868,7 +916,9 @@ namespace tntdb
 
     tntdb::Datetime MultiValue::getDatetime(unsigned n) const
     {
-      if (isNull(n))
+      log_debug("Datetime (" << n << "), type=" << _type);
+
+      if (_nullind[n] != 0)
         throw NullValue();
 
       switch (_type)
