@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2006 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -73,7 +73,12 @@ namespace tntdb
   void PoolConnection::rollbackTransaction()
   {
     connection->rollbackTransaction();
-    // keep transaction state
+    inTransaction = false;
+
+    // When a rollback has been done, this may be a indication, that something
+    // weird has happened, so we do not reuse that connection.
+
+    drop = true;
   }
 
   PoolConnection::size_type PoolConnection::execute(const std::string& query)
@@ -96,6 +101,11 @@ namespace tntdb
     return connection->selectValue(query);
   }
 
+  Statement PoolConnection::prepareWithLimit(const std::string& query, const std::string& limit, const std::string& offset)
+  {
+    return connection->prepareWithLimit(query, limit, offset);
+  }
+
   Statement PoolConnection::prepare(const std::string& query)
   {
     return connection->prepare(query);
@@ -106,6 +116,11 @@ namespace tntdb
     return connection->prepareCached(query, key);
   }
 
+  Statement PoolConnection::prepareCachedWithLimit(const std::string& query, const std::string& limit, const std::string& offset, const std::string& key)
+  {
+    return connection->prepareCachedWithLimit(query, limit, offset, key);
+  }
+
   void PoolConnection::clearStatementCache()
   {
     return connection->clearStatementCache();
