@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -43,13 +43,13 @@ namespace tntdb
 {
   namespace postgresql
   {
-    Connection::Connection(const char* conninfo)
+    Connection::Connection(const std::string& url_, const std::string& username, const std::string& password)
       : transactionActive(0),
         stmtCounter(0)
     {
-      log_debug("PQconnectdb(\"" << conninfo << "\")");
+      log_debug("PQconnectdb(\"" << url_ << "\")");
 
-      conn = PQconnectdb(conninfo);
+      conn = PQconnectdb(url(url_, username, password).c_str());
       if (conn == 0)
         throw std::bad_alloc();
 
@@ -65,6 +65,7 @@ namespace tntdb
       {
         clearStatementCache();
         currvalStmt = tntdb::Statement();
+        lastvalStmt = tntdb::Statement();
 
         log_debug("PQfinish(" << conn << ")");
         PQfinish(conn);
@@ -159,6 +160,25 @@ namespace tntdb
       return tntdb::Statement(new Statement(this, query));
     }
 
+    tntdb::Statement Connection::prepareWithLimit(const std::string& query, const std::string& limit, const std::string& offset)
+    {
+      std::string q = query;
+
+      if (!limit.empty())
+      {
+        q += " limit :";
+        q += limit;
+      }
+
+      if (!offset.empty())
+      {
+        q += " offset :";
+        q += offset;
+      }
+
+      return prepare(q);
+    }
+
     bool Connection::ping()
     {
       log_debug("ping()");
@@ -265,14 +285,9 @@ namespace tntdb
       std::string query = "LOCK TABLE ";
       query += tablename;
       query += exclusive ? " IN ACCESS EXCLUSIVE MODE" : " IN SHARE MODE";
-      log_debug("execute(\"" << query << "\")");
 
-      PGresult* result = PQexec(conn, query.c_str());
-      if (isError(result))
-      {
-        log_error(PQresultErrorMessage(result));
-        throw PgSqlError(query, "PQexec", result, true);
-      }
+      tntdb::Statement lockStmt = prepare(query);
+      lockStmt.execute();
     }
   }
 }
