@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2011 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -44,8 +44,9 @@ namespace tntdb
 {
   namespace replicate
   {
-    Connection::Connection(const char* conninfo)
+    Connection::Connection(const std::string& url, const std::string& username, const std::string& password)
     {
+      const char* conninfo = url.c_str();
       const char* b = conninfo;
       const char* e = conninfo;
       std::vector<std::string> urls;
@@ -68,7 +69,7 @@ namespace tntdb
       for (std::vector<std::string>::const_iterator it = urls.begin(); it != urls.end(); ++it)
       {
         log_debug("connect to " << *it);
-        connections.push_back(connect(*it));
+        connections.push_back(connect(*it, username, password));
         if (!primaryConnection && *it == primaryUrl)
         {
           log_debug("primary connection " << *it);
@@ -147,6 +148,11 @@ namespace tntdb
       return tntdb::Statement(new Statement(this, query));
     }
 
+    tntdb::Statement Connection::prepareWithLimit(const std::string& query, const std::string& limit, const std::string& offset)
+    {
+      return tntdb::Statement(new Statement(this, query, limit, offset));
+    }
+
     bool Connection::ping()
     {
       for (Connections::iterator it = connections.begin(); it != connections.end(); ++it)
