@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2011 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -43,7 +43,7 @@ namespace tntdb
 {
   namespace replicate
   {
-    Statement::Statement(Connection* conn_, const std::string& query)
+    Statement::Statement(Connection* conn_, const std::string& query, const std::string& limit, const std::string& offset)
       : conn(conn_)
     {
       // check if it a select statement
@@ -57,7 +57,10 @@ namespace tntdb
       if (strncasecmp(p, "select", 6) == 0)
       {
         log_debug("select statement detected - prepare on first connection only");
-        statements.push_back(conn->connections.begin()->prepare(query));
+        if (limit.empty() && offset.empty())
+          statements.push_back(conn->connections.begin()->prepare(query));
+        else
+          statements.push_back(conn->connections.begin()->prepareWithLimit(query, limit, offset));
       }
       else
       {
