@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -42,6 +42,7 @@
 #include <sstream>
 #include <limits>
 #include <cxxtools/log.h>
+#include "config.h"
 
 log_define("tntdb.sqlite.statement")
 
@@ -82,12 +83,21 @@ namespace tntdb
 
         // prepare statement
         const char* tzTail;
+#ifdef HAVE_SQLITE3_PREPARE_V2
+        log_debug("sqlite3_prepare_v2(" << conn->getSqlite3() << ", \"" << query
+          << "\", " << &stmt << ", " << &tzTail << ')');
+        int ret = ::sqlite3_prepare_v2(conn->getSqlite3(), query.data(), query.size(), &stmt, &tzTail);
+
+        if (ret != SQLITE_OK)
+          throw Execerror("sqlite3_prepare_v2", conn->getSqlite3(), ret);
+#else
         log_debug("sqlite3_prepare(" << conn->getSqlite3() << ", \"" << query
           << "\", " << &stmt << ", " << &tzTail << ')');
         int ret = ::sqlite3_prepare(conn->getSqlite3(), query.data(), query.size(), &stmt, &tzTail);
 
         if (ret != SQLITE_OK)
           throw Execerror("sqlite3_prepare", conn->getSqlite3(), ret);
+#endif
 
         log_debug("sqlite3_stmt = " << stmt);
 
@@ -292,12 +302,12 @@ namespace tntdb
           throw Execerror("sqlite3_bind_int64", stmt, ret);
       }
     }
-    
+
     void Statement::setUnsigned64(const std::string& col, uint64_t data)
     {
       setInt64(col, (int64_t)data);
     }
-    
+
     void Statement::setDecimal(const std::string& col, const Decimal& data)
     {
       // SQLite 3.4.1 does not support the SQL decimal or numeric types.
@@ -312,7 +322,7 @@ namespace tntdb
       double d = data.getDouble();
       setDouble(col, d);
     }
-    
+
     void Statement::setFloat(const std::string& col, float data)
     {
       setDouble(col, static_cast<double>(data));
@@ -408,13 +418,10 @@ namespace tntdb
       log_debug("sqlite3_step(" << stmt << ')');
       int ret = sqlite3_step(stmt);
 
-      if (ret == SQLITE_ERROR)
-        throw Execerror("sqlite3_step", stmt, ret);
-      else if (ret != SQLITE_DONE)
+      if (ret != SQLITE_DONE && ret != SQLITE_ROW)
       {
-        std::ostringstream msg;
-        msg << "unexpected returncode " << ret << " from sqlite3_step";
-        throw SqliteError("sqlite3_step", msg.str());
+        log_debug("sqlite3_step failed with return code " << ret);
+        throw Execerror("sqlite3_step", stmt, ret);
       }
 
       int n = ::sqlite3_changes(::sqlite3_db_handle(stmt));
@@ -437,9 +444,7 @@ namespace tntdb
         log_debug("sqlite3_step(" << stmt << ')');
         ret = sqlite3_step(stmt);
 
-        if (ret == SQLITE_ERROR)
-          throw Execerror("sqlite3_step", stmt, ret);
-        else if (ret == SQLITE_ROW)
+        if (ret == SQLITE_ROW)
         {
           log_debug("sqlite3_column_count(" << stmt << ')');
           int count = ::sqlite3_column_count(stmt);
@@ -473,9 +478,8 @@ namespace tntdb
         }
         else if (ret != SQLITE_DONE)
         {
-          std::ostringstream msg;
-          msg << "unexpected returncode " << ret;
-          throw SqliteError("sqlite3_step", msg.str());
+          log_debug("sqlite3_step failed with return code " << ret);
+          throw Execerror("sqlite3_step", stmt, ret);
         }
 
       } while (ret == SQLITE_ROW);
@@ -491,9 +495,7 @@ namespace tntdb
       log_debug("sqlite3_step(" << stmt << ')');
       int ret = sqlite3_step(stmt);
 
-      if (ret == SQLITE_ERROR)
-        throw Execerror("sqlite3_step", stmt, ret);
-      else if (ret == SQLITE_DONE)
+      if (ret == SQLITE_DONE)
         throw NotFound();
       else if (ret == SQLITE_ROW)
       {
@@ -526,13 +528,15 @@ namespace tntdb
 
           r->add(name, v);
         }
+
+        reset();
         return row;
       }
       else
       {
-        std::ostringstream msg;
-        msg << "unexpected returncode " << ret;
-        throw SqliteError("sqlite3_step", msg.str());
+        reset();
+        log_debug("sqlite3_step failed with return code " << ret);
+        throw Execerror("sqlite3_step", stmt, ret);
       }
     }
 
@@ -544,12 +548,7 @@ namespace tntdb
       log_debug("sqlite3_step(" << stmt << ')');
       int ret = sqlite3_step(stmt);
 
-      if (ret == SQLITE_ERROR)
-      {
-        log_debug("sqlite3_step returned SQLITE_ERROR");
-        throw Execerror("sqlite3_step", stmt, ret);
-      }
-      else if (ret == SQLITE_DONE)
+      if (ret == SQLITE_DONE)
       {
         log_debug("sqlite3_step returned SQLITE_DONE => NotFound");
         throw NotFound();
@@ -576,13 +575,15 @@ namespace tntdb
         if (txt)
           v = Value(new ValueImpl(
             std::string(static_cast<const char*>(txt), n)));
+
+        reset();
         return v;
       }
       else
       {
-        std::ostringstream msg;
-        msg << "unexpected returncode " << ret;
-        throw SqliteError("sqlite3_step", msg.str());
+        reset();
+        log_debug("sqlite3_step failed with return code " << ret);
+        throw Execerror("sqlite3_step", stmt, ret);
       }
     }
 
