@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -65,16 +65,16 @@ namespace tntdb
     // format hh:mm:ss.sss
     //        0....+....1....+
     char ret[14];
-    ret[0] = '0' + hour / 10;
-    ret[1] = '0' + hour % 10;
+    ret[0] = '0' + _hour / 10;
+    ret[1] = '0' + _hour % 10;
     ret[2] = ':';
-    ret[3] = '0' + minute / 10;
-    ret[4] = '0' + minute % 10;
+    ret[3] = '0' + _minute / 10;
+    ret[4] = '0' + _minute % 10;
     ret[5] = ':';
-    ret[6] = '0' + second / 10;
-    ret[7] = '0' + second % 10;
+    ret[6] = '0' + _second / 10;
+    ret[7] = '0' + _second % 10;
     ret[8] = '.';
-    unsigned short n = millis;
+    unsigned short n = _millis;
     ret[11] = '0' + n % 10;
     n /= 10;
     ret[10] = '0' + n % 10;
@@ -89,6 +89,7 @@ namespace tntdb
     if (!std::isdigit(s[0])
       || !std::isdigit(s[1]))
       throw TypeError();
+
     return (s[0] - '0') * 10
          + (s[1] - '0');
   }
@@ -99,6 +100,7 @@ namespace tntdb
       || !std::isdigit(s[1])
       || !std::isdigit(s[2]))
       throw TypeError();
+
     return (s[0] - '0') * 100
          + (s[1] - '0') * 10
          + (s[2] - '0');
@@ -134,5 +136,5 @@ namespace tntdb
 
     return ret;
   }
-
 }
+
