@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2012 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -61,6 +61,8 @@ class TntdbBaseTest : public cxxtools::unit::TestSuite
       registerMethod("testSelectMultiplePlaceholder", *this, &TntdbBaseTest::testSelectMultiplePlaceholder);
       registerMethod("testSelectCursorPlaceholder", *this, &TntdbBaseTest::testSelectCursorPlaceholder);
       registerMethod("testTransaction", *this, &TntdbBaseTest::testTransaction);
+      registerMethod("testLimit", *this, &TntdbBaseTest::testLimit);
+      registerMethod("testLimitOffset", *this, &TntdbBaseTest::testLimitOffset);
     }
 
     void setUp()
@@ -409,6 +411,71 @@ class TntdbBaseTest : public cxxtools::unit::TestSuite
 
     }
 
+    void testLimit()
+    {
+      conn.execute("insert into tntdbtest(intcol) values(4)");
+      conn.execute("insert into tntdbtest(intcol) values(5)");
+      conn.execute("insert into tntdbtest(intcol) values(3)");
+      conn.execute("insert into tntdbtest(intcol) values(9)");
+
+      tntdb::Statement stmt = conn.prepareWithLimit("select intcol from tntdbtest order by 1", "l");
+      stmt.set("l", 2);
+
+      int intVal = 0;
+      bool notNull;
+
+      tntdb::Statement::const_iterator cur = stmt.begin();
+      CXXTOOLS_UNIT_ASSERT(cur != stmt.end());
+
+      notNull = (*cur)[0].get(intVal);
+      CXXTOOLS_UNIT_ASSERT(notNull);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(intVal, 3);
+
+      ++cur;
+      CXXTOOLS_UNIT_ASSERT(cur != stmt.end());
+
+      notNull = (*cur)[0].get(intVal);
+      CXXTOOLS_UNIT_ASSERT(notNull);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(intVal, 4);
+
+      ++cur;
+      CXXTOOLS_UNIT_ASSERT(cur == stmt.end());
+
+    }
+
+    void testLimitOffset()
+    {
+      conn.execute("insert into tntdbtest(intcol) values(4)");
+      conn.execute("insert into tntdbtest(intcol) values(5)");
+      conn.execute("insert into tntdbtest(intcol) values(3)");
+      conn.execute("insert into tntdbtest(intcol) values(9)");
+
+      tntdb::Statement stmt = conn.prepareWithLimit("select intcol from tntdbtest order by 1", "l", "o");
+      stmt.set("l", 2)
+          .set("o", 1);
+
+      int intVal = 0;
+      bool notNull;
+
+      tntdb::Statement::const_iterator cur = stmt.begin();
+      CXXTOOLS_UNIT_ASSERT(cur != stmt.end());
+
+      notNull = (*cur)[0].get(intVal);
+      CXXTOOLS_UNIT_ASSERT(notNull);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(intVal, 4);
+
+      ++cur;
+      CXXTOOLS_UNIT_ASSERT(cur != stmt.end());
+
+      notNull = (*cur)[0].get(intVal);
+      CXXTOOLS_UNIT_ASSERT(notNull);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(intVal, 5);
+
+      ++cur;
+      CXXTOOLS_UNIT_ASSERT(cur == stmt.end());
+
+    }
+
 };
 
 cxxtools::unit::RegisterTest<TntdbBaseTest> register_TntdbBaseTest;
