@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2010 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -52,6 +52,7 @@ class TntdbDecimalTest : public cxxtools::unit::TestSuite
       registerMethod("testFromString", *this, &TntdbDecimalTest::testFromString);
       registerMethod("testToString", *this, &TntdbDecimalTest::testToString);
       registerMethod("testInt", *this, &TntdbDecimalTest::testInt);
+      registerMethod("testIntExp", *this, &TntdbDecimalTest::testIntExp);
       registerMethod("testCompare", *this, &TntdbDecimalTest::testCompare);
     }
 
@@ -190,6 +191,10 @@ class TntdbDecimalTest : public cxxtools::unit::TestSuite
       l = d.getInteger<long>();
       CXXTOOLS_UNIT_ASSERT_EQUALS(l, 100l);
 
+      d = tntdb::Decimal(45, 3);
+      l = d.getInteger<long>();
+      CXXTOOLS_UNIT_ASSERT_EQUALS(l, 45000l);
+
       d = tntdb::Decimal(std::numeric_limits<long>::max(), 0);
       l = d.getInteger<long>();
       CXXTOOLS_UNIT_ASSERT_EQUALS(l, std::numeric_limits<long>::max());
@@ -204,6 +209,22 @@ class TntdbDecimalTest : public cxxtools::unit::TestSuite
 
     }
 
+    void testIntExp()
+    {
+      tntdb::Decimal d("453000");
+      long l = d.getInteger<long>(-3);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(l, 453);
+
+      d = tntdb::Decimal("45.6");
+      l = d.getInteger<long>(1);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(l, 456);
+
+      d = tntdb::Decimal("-78.334");
+      l = d.getInteger<long>(4);
+      CXXTOOLS_UNIT_ASSERT_EQUALS(l, -783340);
+
+    }
+
     void testCompare()
     {
       tntdb::Decimal d0(45, 3);
